/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

/** \file
 *
 * This library manages the list of device drivers.
 */

#ifndef XCSOAR_DEVICE_REGISTRY_HPP
#define XCSOAR_DEVICE_REGISTRY_HPP

#include "Compiler.h"

#include <tchar.h>

struct DeviceRegister;

gcc_const
const DeviceRegister *
GetDriverByIndex(unsigned i);

gcc_pure
const DeviceRegister *
FindDriverByName(const TCHAR *name);

/**
 * Find the driver with the specified name, and return its display
 * name.  If no such driver was found, the specified name is returned.
 */
gcc_pure
const TCHAR *
FindDriverDisplayName(const TCHAR *name);

#endif
